/**
 * --------------------------------------------------------------------------
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010-2012 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.classloader.model {

import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.model.ModelLocator;

import mx.collections.ArrayCollection;

import org.ow2.jonas.admin.classloader.business.MyDelegate;
import org.ow2.jonas.admin.classloader.view.ClassLoaderView;
import org.ow2.jonas.admin.classloader.view.NodeVisualGraph;


/**
 * Cairngorm Model Locator for the ClassLoader module
 * @author Florent Benoit
 */
[Bindable]
public class ClassLoaderModelLocator implements ModelLocator {

    /**
     * Link to the view.
     */
    private var classLoaderView:ClassLoaderView = null;

    /**
     * XML Content for the report on classloader for a given application
     */
    private var xmlClassLoaderInfo:XML = null;

    /**
     * XML Content for searching packages/classes
     */
    private var xmlSearchResultPackagesClasses:XML = null;

    /**
     * Array result for searching system resources
     */
    private var arraySearchResultSystemResources:Array = null;


    /**
     * If nothing has been found during the search
     */
    private var nothingFoundDuringSearch:Boolean = false;


    /**
     * ObjectName of the selected classLoader.
     */
    public var selectedClassLoaderObjectName:String = null;


    /**
     * XML Content for searching classes
     */
    public var xmlClassLoaderObjectNameLoadClassResult:XML = null;

    /**
     * Array result for searching system resources
     */
    public var arrayClassLoaderObjectNameGetResourcesResult:Array = null;


    /**
     * Visual Graph component.
     */
    public var vgraph:NodeVisualGraph = null;

    /**
     * Showing Graph ?
     */
    public var showingGraph:Boolean = false;

    /**
     * Selected XML fragment
     */
    public var xmlSelectedClassLoader:XML = null;


    /**
     * Information on all the Applications found on the server.
     */
    [ArrayElementType("org.ow2.jonas.admin.classloader.vo.ApplicationInfoVO")]
    public var standaloneApplications:ArrayCollection;

    public const CLASS_SEARCH_MODE:String = "Class";
    public const PACKAGE_SEARCH_MODE:String = "Package";
    public const RESOURCE_SEARCH_MODE:String = "Resource";

    /**
     * SearchMode.
     */
    private var searchModeValue:String = CLASS_SEARCH_MODE;


    public var searchOK:Boolean = false;

    /**
     * Constructor
     */
    public function ClassLoaderModelLocator() {
    }

    /**
     * unique instance of delegate
     */
    private var _delegate:MyDelegate = null;

    public function getDelegate():MyDelegate {
        if (_delegate == null) {
            _delegate = new MyDelegate();
        }
        return _delegate;
    }


    public function get searchMode():String {
        return searchModeValue;
    }


    public function set searchMode(searchModeValue:String):void {
        this.searchModeValue = searchModeValue;
    }

    public function set view(classLoaderView:ClassLoaderView):void {
        this.classLoaderView = classLoaderView;
    }

    public function set xmlPackages(xmlSearchResultPackagesClasses:XML):void {
        this.xmlSearchResultPackagesClasses = xmlSearchResultPackagesClasses;
    }

    public function get xmlPackages():XML {
        return xmlSearchResultPackagesClasses;
    }


    public function set xmlClassLoaderInfoReport(xmlClassLoaderInfo:XML):void {
        this.xmlClassLoaderInfo = xmlClassLoaderInfo;
    }

    public function get xmlClassLoaderInfoReport():XML {
        return xmlClassLoaderInfo;
    }


    public function set systemResources(arraySearchResultSystemResources:Array):void {
        this.arraySearchResultSystemResources = arraySearchResultSystemResources;
    }

    public function get systemResources():Array {
        return arraySearchResultSystemResources;
    }


    public function dispatch(event:CairngormEvent):void {
        classLoaderView.dispatchEvent(event);

    }


    public function set nothingHasBeenFoundDuringSearch(nothingFoundDuringSearch:Boolean):void {
        this.nothingFoundDuringSearch = nothingFoundDuringSearch;
    }

    public function get nothingHasBeenFoundDuringSearch():Boolean {
        return nothingFoundDuringSearch;
    }

}
}
